@@ -13,19 +13,19 @@ from pyknp_eventgraph import make_image
 
 def evg():
     parser = argparse.ArgumentParser()
-    parser.add_argument('--output', '-o', default='', help='path to output')
+    parser.add_argument("--output", "-o", default="", help="path to output")
     args = parser.parse_args()
 
-    basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    basicConfig(format="%(asctime)s - %(name)s - %(levelname)s - %(message)s")
 
     knp = KNP()
     results = []
-    chunk = ''
-    for line in codecs.getreader('utf-8')(getattr(sys.stdin, 'buffer', sys.stdin)):
+    chunk = ""
+    for line in codecs.getreader("utf-8")(getattr(sys.stdin, "buffer", sys.stdin)):
         chunk += line
-        if line.strip() == 'EOS':
+        if line.strip() == "EOS":
             results.append(knp.result(chunk))
-            chunk = ''
+            chunk = ""
     evg_ = EventGraph.build(results)
     if args.output:
         evg_.save(args.output)
@@ -35,15 +35,15 @@ def evg():
 
 def evgviz():
     parser = argparse.ArgumentParser()
-    parser.add_argument('IN', help='path to input')
-    parser.add_argument('OUT', help='path to output')
-    parser.add_argument('--exclude-detail', action='store_true', help='exclude detail information of events')
-    parser.add_argument('--exclude-original-text', action='store_true', help='exclude original texts')
-    parser.add_argument('--binary', '-b', action='store_true', help='whether the input is binary')
+    parser.add_argument("IN", help="path to input")
+    parser.add_argument("OUT", help="path to output")
+    parser.add_argument("--exclude-detail", action="store_true", help="exclude detail information of events")
+    parser.add_argument("--exclude-original-text", action="store_true", help="exclude original texts")
+    parser.add_argument("--binary", "-b", action="store_true", help="whether the input is binary")
     args = parser.parse_args()
 
     if args.binary:
-        with open(args.IN, 'rb') as f:
+        with open(args.IN, "rb") as f:
             evg_ = EventGraph.load(f, binary=args.binary)
     else:
         with open(args.IN) as f:
