@@ -27,7 +27,7 @@ class PAS(Component):
         arguments (Dict[str, List[Argument]]): A mapping of a case to arguments.
     """
 
-    def __init__(self, event: 'Event', pas: Optional[PyknpPAS] = None):
+    def __init__(self, event: "Event", pas: Optional[PyknpPAS] = None):
         self.event: Event = event
         self.sid: str = event.sid
         self.ssid: int = event.ssid
@@ -43,7 +43,7 @@ class PAS(Component):
                 case: [argument.to_dict() for argument in argument_list if argument.to_dict()]
                 for case, argument_list in self.arguments.items()
                 if any(argument.to_dict() for argument in argument_list)
-            }
+            },
         )
 
     def to_string(self) -> str:
@@ -53,29 +53,23 @@ class PAS(Component):
         for case, argument_list in self.arguments.items():
             for argument in argument_list:
                 if argument.head_reps:
-                    arguments.append(f'{case}: {argument.head_reps}')
+                    arguments.append(f"{case}: {argument.head_reps}")
         return f'<PAS, predicate: {predicate}, arguments: {"{" + ", ".join(arguments) + "}" if arguments else "None"}>'
 
 
 class PASBuilder(Builder):
-
-    def __call__(self, event: 'Event') -> PAS:
-        logger.debug('Create a PAS.')
+    def __call__(self, event: "Event") -> PAS:
         pas = PAS(event, event.head.pas)
         PredicateBuilder()(pas)
         ArgumentsBuilder()(pas)
         event.pas = pas
-        logger.debug('Successfully created a PAS.')
         return pas
 
 
 class JsonPASBuilder(Builder):
-
-    def __call__(self, event: 'Event', dump: dict) -> PAS:
-        logger.debug('Create a PAS.')
+    def __call__(self, event: "Event", dump: dict) -> PAS:
         pas = PAS(event)
-        JsonPredicateBuilder()(pas, dump['predicate'])
-        JsonArgumentsBuilder()(pas, dump['argument'])
+        JsonPredicateBuilder()(pas, dump["predicate"])
+        JsonArgumentsBuilder()(pas, dump["argument"])
         event.pas = pas
-        logger.debug('Successfully created a PAS.')
         return pas
