@@ -32,7 +32,7 @@ class Relation(Component):
         reliable (bool): If true, a syntactic dependency is not ambiguous.
     """
 
-    def __init__(self, modifier: 'Event', head: 'Event', label: str, surf: str, head_tid: int, reliable: bool):
+    def __init__(self, modifier: "Event", head: "Event", label: str, surf: str, head_tid: int, reliable: bool):
         self.modifier: Optional[Event] = modifier
         self.head: Optional[Event] = head
         self.label: str = label
@@ -43,22 +43,16 @@ class Relation(Component):
     def to_dict(self) -> dict:
         """Convert this object into a dictionary."""
         return dict(
-            event_id=self.head.evid,
-            label=self.label,
-            surf=self.surf,
-            reliable=self.reliable,
-            head_tid=self.head_tid
+            event_id=self.head.evid, label=self.label, surf=self.surf, reliable=self.reliable, head_tid=self.head_tid
         )
 
     def to_string(self) -> str:
         """Convert this object into a string."""
-        return f'<Relation, label: {self.label}, modifier_evid: {self.modifier.evid}, head_evid: {self.head.evid}>'
+        return f"<Relation, label: {self.label}, modifier_evid: {self.modifier.evid}, head_evid: {self.head.evid}>"
 
 
 def filter_relations(
-        relations: List[Relation],
-        labels: List[str] = None,
-        head_tids: List[int] = None
+    relations: List[Relation], labels: List[str] = None, head_tids: List[int] = None
 ) -> List[Relation]:
     """Filter relations.
 
@@ -78,39 +72,33 @@ def filter_relations(
 
 
 class RelationBuilder:
-
-    def __call__(self, modifier: 'Event', head: 'Event', label: str, surf: str = '', head_tid: int = -1,
-                 reliable: bool = False) -> Relation:
-        logger.debug('Create a relation')
+    def __call__(
+        self, modifier: "Event", head: "Event", label: str, surf: str = "", head_tid: int = -1, reliable: bool = False
+    ) -> Relation:
         relation = Relation(modifier, head, label, surf, head_tid, reliable)
         modifier.outgoing_relations.append(relation)
         head.incoming_relations.append(relation)
-        logger.debug('Successfully created a relation.')
         return relation
 
 
 class JsonRelationBuilder(Builder):
-
     def __call__(self, modifier_evid: int, head_evid: int, dump: dict) -> Relation:
-        logger.debug('Create a relation')
         modifier = Builder.evid_event_map[modifier_evid]
         head = Builder.evid_event_map[head_evid]
-        relation = Relation(modifier, head, dump['label'], dump['surf'], dump['head_tid'], dump['reliable'])
+        relation = Relation(modifier, head, dump["label"], dump["surf"], dump["head_tid"], dump["reliable"])
         modifier.outgoing_relations.append(relation)
         head.incoming_relations.append(relation)
-        logger.debug('Successfully created a relation.')
         return relation
 
 
 class RelationsBuilder(Builder):
-
-    def __call__(self, event: 'Event') -> List[Relation]:
+    def __call__(self, event: "Event") -> List[Relation]:
         relations: List[Relation] = []
         for relation in self._get_outgoing_relations(event):
             relations.append(relation)
         return relations
 
-    def _get_outgoing_relations(self, event: 'Event') -> List[Relation]:
+    def _get_outgoing_relations(self, event: "Event") -> List[Relation]:
         relations: List[Relation] = []
 
         parent_event = self._find_parent(event)
@@ -124,46 +112,51 @@ class RelationsBuilder(Builder):
             reliable = False
 
         # Adnominal.
-        if event.parent and event.end.features['節-区切'] == '連体修飾':
-            relations.append(RelationBuilder()(event, event.parent, '連体修飾', head_tid=event.end.parent_id,
-                                               reliable=reliable))
+        if event.parent and event.end.features["節-区切"] == "連体修飾":
+            relations.append(
+                RelationBuilder()(event, event.parent, "連体修飾", head_tid=event.end.parent_id, reliable=reliable)
+            )
 
         # Sentential complement.
-        if event.parent and event.end.features['節-区切'] == '補文':
-            relations.append(RelationBuilder()(event, event.parent, '補文', head_tid=event.end.parent_id,
-                                               reliable=reliable))
+        if event.parent and event.end.features["節-区切"] == "補文":
+            relations.append(
+                RelationBuilder()(event, event.parent, "補文", head_tid=event.end.parent_id, reliable=reliable)
+            )
 
         # Discourse relation.
         if not relations:
-            for discourse_relation in re.findall('<談話関係[;:](.+?)>', event.end.fstring):
-                tmp, label = discourse_relation.split(':')
-                sdist, tid, sid = tmp.split('/')
+            for discourse_relation in re.findall("<談話関係[;:](.+?)>", event.end.fstring):
+                tmp, label = discourse_relation.split(":")
+                sdist, tid, sid = tmp.split("/")
                 head_event = Builder.stid_event_map.get((event.ssid + int(sdist), int(tid)), None)
                 if head_event:
-                    relations.append(RelationBuilder()(event, head_event, f'談話関係:{label}'))
+                    relations.append(RelationBuilder()(event, head_event, f"談話関係:{label}"))
 
         # Clausal function.
         if not relations and event.parent:
-            for clause_function in re.findall('<節-機能-(.+?)>', event.end.fstring):
-                if ':' in clause_function:
-                    label, surf = clause_function.split(':')
+            for clause_function in re.findall("<節-機能-(.+?)>", event.end.fstring):
+                if ":" in clause_function:
+                    label, surf = clause_function.split(":")
                 else:
-                    label, surf = clause_function, ''
-                relations.append(RelationBuilder()(event, event.parent, label, surf=surf, head_tid=event.end.parent_id,
-                                                   reliable=reliable))
+                    label, surf = clause_function, ""
+                relations.append(
+                    RelationBuilder()(
+                        event, event.parent, label, surf=surf, head_tid=event.end.parent_id, reliable=reliable
+                    )
+                )
 
         # Clausal parallel relation.
         if not relations and event.parent:
-            if event.end.dpndtype == 'P':
-                relations.append(RelationBuilder()(event, event.parent, '並列', reliable=reliable))
+            if event.end.dpndtype == "P":
+                relations.append(RelationBuilder()(event, event.parent, "並列", reliable=reliable))
 
         # Clausal dependency.
         if not relations and event.parent:
-            relations.append(RelationBuilder()(event, event.parent, '係り受け', reliable=reliable))
+            relations.append(RelationBuilder()(event, event.parent, "係り受け", reliable=reliable))
         return relations
 
     @staticmethod
-    def _find_parent(event: 'Event') -> Optional['Event']:
+    def _find_parent(event: "Event") -> Optional["Event"]:
         parent_tag: Optional[Tag] = event.head.parent
         while parent_tag:
             for parent_event_cand in filter(lambda event_: event.evid < event_.evid, event.sentence.events):
